

#--------------------------------------------------------------
# Age-Length keys (ALK)
#--------------------------------------------------------------
cat("\n###########################\n")
cat("Age-Length keys (ALK)\n")
cat("###########################\n")
cat("\n")
library(ggplot2)
file_TE <- dir(path = paste(wd,"input/TE",sep="/"), pattern = "\\.csv$", all.files = FALSE, full.names = FALSE, include.dirs = FALSE, no.. = TRUE)
if (length(file_TE) > 1){
	warning("there is more than one file in the TE folder. Please retain only the right one.")
} else if (length(file_TE) == 0) {
	warning("No files in the TE folder. Please insert a file in the folder.")
} else if (length(file_TE) == 1) {
	TE <- read.table(paste(wd,"input/TE",file_TE, sep="/"), sep=";", header=T) 
	
	file_TA <- dir(path = paste(wd,"input/TA",sep="/"), pattern = "\\.csv$", all.files = FALSE, full.names = FALSE, include.dirs = FALSE, no.. = TRUE)
	
	if (length(file_TA) > 1){
		warning("there is more than one file in the TA folder. Please retain only the right one.")
	} else if (length(file_TA) == 0) {
		warning("No files in the TA folder. Please insert a file in the folder.")
	} else if (length(file_TA) == 1) {
	TA <- read.table(paste(wd,"input/TA",file_TA, sep="/"), sep=";", header=T) 
	
	
	if (nrow(TE)>0 & nrow(TA)>0) {
		cat("TE file correctly read\n")
		source(file.path(wd,"scripts/functions.r"))
		
		if (file.exists(file.path(wd,"output/ALK"))) {
			setwd(wd)
		} else {
			dir.create(file.path(wd,"output/ALK"), showWarnings = FALSE)
			setwd(wd)
		}
		
		
		GEAR <- unique(TA$GEAR)[1]
		YEARS <- sort(unique(TE$YEAR))
		nYEARS <- length(YEARS)
		
		n_years <- as.numeric(dlgInput(paste("There are (", length(YEARS),") year/s of survey in TE table\nHow many of the last years do you want to consider in the ALK analysis? --> ", sep=""), default=length(YEARS),Sys.info()[""])$res)
		
		#YEARS
		if (!is.na(n_years) & n_years <= nYEARS & n_years >0) {
			n_years <- n_years
		} else {
			n_years <- nYEARS
		}
		
		# SPECIES
		if (!exists("sspp")){
		species <- toupper(dlgInput("Select the species (MEDITS code: 'ARISFOL') ---> ", default="ARISFOL",Sys.info()[""])$res)
		#species <- readline("Select the species (rubin code: 'ARITANT') ---> ")
		species[2] <- substr(species,5,7)
		species[1] <- substr(species[1],1,4)
		sspp <- paste(species[1],species[2], sep="")
		}
		
		# COUNTRY
		if (exists("country_analysis")) {
			GSA <- unique(TE$AREA)[1]
			source(file.path(wd,"scripts/functions.r"))
			ALK(TE, GEAR, GSA, country = country_analysis, sp=sspp, years = n_years)	
		} else {
			TA_country <- sort(unique(as.character(TA$COUNTRY)))
			TE_country <- sort(unique(as.character(TE$COUNTRY)))
			l_country <- length(TA_country)
			
			for (i in 1:l_country){
				if (!(TA_country[i] %in% TE_country)){warning(paste("The country ",TA_country[i]," is not present in the TE file.", sep=""))}
			}
			
			if (l_country==1){
				
				check_country ="Y"
				country_analysis <- TA_country
				
			} else {
				
				# cat("\f")
				print(data.frame(Countries=TA_country))
				
				check_country <-  menu(c("Yes", "No"), title=  paste("There are ",l_country," countries in the TA file.\n Do you want to perform the analysis on the entire GSA area?",sep="")  )
				# check_country <- toupper(as.character(readline(paste("there are ",l_country," countries in the TA file.\n Do you want to perform the analysis on the entire GSA area? (Y/y) --> "))))
				if (check_country == 1) {
					check_country ="Y"
					country_analysis <<- TA_country
				} else {
					cat("\f")
					check_country ="N"
					# print(data.frame(Countries = TA_country))
					sel_country <- menu(TA_country ,title=  "Select the country for the analysis (use only numbers) -> "  )
					# sel_country <- as.numeric(readline("Select the country for the analysis -> "))
					country_analysis <<- TA_country[sel_country]
				}
			} # close -->if  length(l_country)==1
			GSA <- unique(TE$AREA)[1]
			source(file.path(wd,"scripts/functions.r"))
			ALK(TE, GEAR, GSA, country = country_analysis, sp=sspp, years = n_years)
		}
		
	}
	}
}

#--------------------------------------------------------------
# Length-Weight parameters
#--------------------------------------------------------------
cat("\n###########################\n")
cat("Length-Weight parameters\n")
cat("###########################\n")
cat("\n")

file_TE <- dir(path = paste(wd,"input/TE",sep="/"), pattern = "\\.csv$", all.files = FALSE, full.names = FALSE, include.dirs = FALSE, no.. = TRUE)
if (length(file_TE) > 1){
	warning("there is more than one file in the TE folder. Please retain only the right one.")
} else if (length(file_TE) == 0) {
	warning("No files in the TE folder. Please insert a file in the folder.")
} else if (length(file_TE) == 1) {
	TE <- read.table(paste(wd,"input/TE",file_TE, sep="/"), sep=";", header=T) 
	cat("TE file correctly read\n")

	file_TA <- dir(path = paste(wd,"input/TA",sep="/"), pattern = "\\.csv$", all.files = FALSE, full.names = FALSE, include.dirs = FALSE, no.. = TRUE)
	
	if (length(file_TA) > 1){
		warning("there is more than one file in the TA folder. Please retain only the right one.")
	} else if (length(file_TA) == 0) {
		warning("No files in the TA folder. Please insert a file in the folder.")
	} else if (length(file_TA) == 1) {
		TA <- read.table(paste(wd,"input/TA",file_TA, sep="/"), sep=";", header=T) 
		
		if (nrow(TE)>0 & nrow(TA)>0) {
		
		GEAR <- unique(TA$GEAR)[1]
		YEARS <- sort(unique(TE$YEAR))
		nYEARS <- length(YEARS)
		
		n_years <- as.numeric(dlgInput(paste("There are (", length(YEARS),") year/s of survey in TE table\nHow many of the last years do you want to consider in the Length-Weight analysis? --> ", sep=""), default=length(YEARS),Sys.info()[""])$res)
		
		#YEARS
		if (!is.na(n_years) & n_years <= nYEARS & n_years >0) {
			n_years <- n_years
		} else {
			n_years <- nYEARS
		}
		
		
		# SPECIES
		if (!exists("sspp")){
			species <- toupper(dlgInput("Select the species (MEDITS code: 'ARISFOL') ---> ", default="ARISFOL",Sys.info()[""])$res)
			species[2] <- substr(species,5,7)
			species[1] <- substr(species[1],1,4)
			sspp <- paste(species[1],species[2], sep="")
		}
		
		GSA <- unique(TE$AREA)[1]
		
		# COUNTRY
		if (exists("country_analysis")) {
			source(file.path(wd,"scripts/functions.r"))
			LW(TE,sspp,GEAR,GSA,country=country_analysis,n_records=5)	
		} else {
			TA_country <- sort(unique(as.character(TA$COUNTRY)))
			TE_country <- sort(unique(as.character(TE$COUNTRY)))
			l_country <- length(TA_country)
			
			for (i in 1:l_country){
				if (!(TA_country[i] %in% TE_country)){warning(paste("The country ",TA_country[i]," is not present in the TE file.", sep=""))}
			}
			
			if (l_country==1){
				
				check_country ="Y"
				country_analysis <- TA_country
				
			} else {
				
				# cat("\f")
				print(data.frame(Countries=TA_country))
				
				check_country <-  menu(c("Yes", "No"), title=  paste("There are ",l_country," countries in the TA file.\n Do you want to perform the analysis on the entire GSA area?",sep="")  )
				# check_country <- toupper(as.character(readline(paste("there are ",l_country," countries in the TA file.\n Do you want to perform the analysis on the entire GSA area? (Y/y) --> "))))
				if (check_country == 1) {
					check_country ="Y"
					country_analysis <<- TA_country
				} else {
					cat("\f")
					check_country ="N"
					# print(data.frame(Countries = TA_country))
					sel_country <- menu(TA_country ,title=  "Select the country for the analysis (use only numbers) -> "  )
					# sel_country <- as.numeric(readline("Select the country for the analysis -> "))
					country_analysis <<- TA_country[sel_country]
				}
			} # close -->if  length(l_country)==1
			GSA <- unique(TE$AREA)[1]
			source(file.path(wd,"scripts/functions.r"))
			LW(TE,sspp,GEAR,GSA,country=country_analysis,n_records=5)
		}
	}
	}
}
