cat("\n###########################\n")
cat("Analysis on TL data\n")
cat("###########################\n")
cat("\n")


file_TA <- dir(path = paste(wd,"input/TA",sep="/"), pattern = "\\.csv$", all.files = FALSE, full.names = FALSE, include.dirs = FALSE, no.. = TRUE)

if (length(file_TA) > 1){
	TA_available = FALSE
	warning("There is more than one file in the TA folder. Please retain only the right one.")
} else if (length(file_TA) == 0) {
	TA_available = FALSE
	warning("No files in the TA folder. Please insert a file in the folder.")
} else if (length(file_TA) == 1) {
	TA_available = TRUE
	TA <- read.table(paste(wd,"input/TA",file_TA, sep="/"), sep=";", header=T) 
		}

file_TL <- dir(path = paste(wd,"input/TL",sep="/"), pattern = "\\.csv$", all.files = FALSE, full.names = FALSE, include.dirs = FALSE, no.. = TRUE)
if (length(file_TL) > 1){
	warning("There is more than one file in the TL folder. Please retain only the right one.")
} else if (length(file_TL) == 0) {
	warning("No files in the TL folder. Please insert a file in the folder.")
} else if (length(file_TL) == 1) {
	TL <- read.table(paste(wd,"input/TL",file_TL, sep="/"), sep=";", header=T) 
	# cat("TL file correctly read\n")
	if (nrow(TL)>0 & TA_available & nrow(TA)>0) {
		
		if (file.exists(file.path(wd,"output/Litter"))) {
			setwd(wd)
		} else {
			dir.create(file.path(wd,"output/Litter"), showWarnings = FALSE)
			setwd(wd)
		}
		
		{
			if ("LITTER_SUB.CATEGORY" %in% colnames(TL)){
				colnames(TL)[which(colnames(TL)=="LITTER_SUB.CATEGORY")] <- "LITTER_SUB-CATEGORY"
			}
			if ("TOTAL_WEIGHT_IN_THE_SUB.CATEGORY_HAUL" %in% colnames(TL)){
				colnames(TL)[which(colnames(TL)=="TOTAL_WEIGHT_IN_THE_SUB.CATEGORY_HAUL")] <- "TOTAL_WEIGHT_IN_THE_SUB-CATEGORY_HAUL"
			}
			if ("TOTAL_NUMBER_IN_THE_SUB.CATEGORY_HAUL" %in% colnames(TL)){
				colnames(TL)[which(colnames(TL)=="TOTAL_NUMBER_IN_THE_SUB.CATEGORY_HAUL")] <- "TOTAL_NUMBER_IN_THE_SUB-CATEGORY_HAUL"
			}
		}
		
		
		#########################
		###   filtro COUNTRY  ###
		#########################
		TA_country <- sort(unique(as.character(TA$COUNTRY)))
		TL_country <- sort(unique(as.character(TL$COUNTRY)))
		l_country <- length(TL_country)
		
		for (i in 1:l_country){
			if (!(TA_country[i] %in% TL_country)){warning(paste("The country ",TA_country[i]," is not present in the TL file.", sep=""))}
		}
		if (l_country==1){
			
			check_country ="Y"
			country_analysis <- TA_country
			
		} else {
			
			# cat("\f")
			print(data.frame(Countries=TA_country))
			
			check_country <-  menu(c("Yes", "No"), title=  paste("There are ",l_country," countries in the TA file.\n Do you want to perform the analysis on the entire GSA area?",sep="")  )
			if (check_country == 1) {
				check_country ="Y"
				country_analysis <<- TA_country
			} else {
				cat("\f")
				check_country ="N"
				# print(data.frame(Countries = TA_country))
				sel_country <- menu(TA_country ,title=  "Select the country for the analysis (use only numbers) -> "  )
				# sel_country <- as.numeric(readline("Select the country for the analysis -> "))
				country_analysis <<- TA_country[sel_country]
			}
		}# close -->if  length(l_country)==1
		
		#--------------  COUNTRY --------------------

		
		source(file.path(wd,"scripts/Indices_LITTER_(Random_Stratified_Sampling).R"))
		# source(file.path(wd,"scripts/merge_TA-TL.r"))

		codes_category <- sort(unique(TL$LITTER_CATEGORY))
		codes_category <- codes_category[!(codes_category %in% "L0")]
		### impostare un ciclo sulle categorie
		for (c in 1:length(codes_category)){
			cat("\n###########################\n")
			cat(paste0("category ",codes_category[c],"\n"))
			cat("###########################\n")
			cat("\n")
			indexTL(TA,TL,var = "Ncat_km2",level="category",code=codes_category[c],depth_range=depth_strata, country = country_analysis)
		}
		
		codes_subcategory <- sort(unique(paste(toupper(TL$LITTER_CATEGORY),toupper(TL$'LITTER_SUB-CATEGORY'),sep="_")))
		codes_subcategory <- codes_subcategory[!(codes_subcategory %in% c("L0_0", "L0_NA", "L1_NA", "L2_NA", "L3_NA", "L4_NA", "L5_NA", "L6_NA", "L7_NA", "L8_NA", "L9_NA"))]
		TL$LITTER_CATEGORY <- toupper(TL$LITTER_CATEGORY)
		TL$'LITTER_SUB-CATEGORY' <- toupper(TL$'LITTER_SUB-CATEGORY')
		### impostare un ciclo sulle categorie
		for (c in 1:length(codes_subcategory)){
			cat("\n###########################\n")
			cat(paste0("category ",codes_subcategory[c],"\n"))
			cat("###########################\n")
			cat("\n")
			indexTL(TA,TL,var = "Ncat_km2",level="subcategory",code=codes_subcategory[c],depth_range=depth_strata, country = country_analysis)
		}
		
	} else {
		message("Analysis interrupted for lack of data. Please, check TA & TL availability")
	}
}
